about summary refs log tree commit diff
path: root/sysdeps/i386/dl-machine.h
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/i386/dl-machine.h')
-rw-r--r--sysdeps/i386/dl-machine.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/sysdeps/i386/dl-machine.h b/sysdeps/i386/dl-machine.h
index a6d8974ab3..87d924821a 100644
--- a/sysdeps/i386/dl-machine.h
+++ b/sysdeps/i386/dl-machine.h
@@ -227,9 +227,10 @@ _dl_start_user:\n\
 	leal (%esp,%eax,4), %esp\n\
 	# Push back the modified argument count.\n\
 	pushl %ecx\n\
-	# Push _dl_default_scope[2] as argument in _dl_init_next call below.\n\
-	movl _dl_default_scope@GOT(%ebx), %eax\n\
-	movl 8(%eax), %esi\n\
+	# Push the searchlist of the main object as argument in\n\
+	# _dl_init_next call below.\n\
+	movl _dl_main_searchlist@GOT(%ebx), %eax\n\
+	movl (%eax), %esi\n\
 0:	movl %esi,%eax\n\
 	# Call _dl_init_next to return the address of an initializer\n\
 	# function to run.\n\